@@ -7,7 +7,7 @@ from torch import device as torch_device
 import os
 import gc
 from tqdm import tqdm
-from typing import Optional, Tuple
+from typing import Optional, Tuple, Dict
 from scipy.spatial.distance import pdist
 import random
 import re
@@ -27,9 +27,12 @@ from particleanalyzer.core.ImagePreprocessor import ImagePreprocessor
 from particleanalyzer.core.StatisticsBuilder import StatisticsBuilder
 from particleanalyzer.core.languages import translations
 from particleanalyzer.core.language_context import LanguageContext
+from particleanalyzer.core.PointManager import PointManager
 
 lang = "en"
 
+point_manager = PointManager()
+
 
 class ParticleAnalyzer:
     SCALE_OPTIONS = {
@@ -122,6 +125,7 @@ class ParticleAnalyzer:
             None,
             None,
             None,
+            None,
             gr.update(visible=False),
             gr.update(visible=False),
             None,
@@ -133,12 +137,14 @@ class ParticleAnalyzer:
             None,
             None,
             gr.update(visible=False),
+            gr.update(visible=False),
         )
 
     def analyze_image(
         self,
-        image: np.ndarray,
         image2: Optional[np.ndarray],
+        scale: float,
+        points_scale: tuple,
         scale_input: float,
         confidence_threshold: float,
         scale_selector: str,
@@ -178,24 +184,16 @@ class ParticleAnalyzer:
                 bar_format="{l_bar}{bar}| {n_fmt}/{total_fmt} [{elapsed}<{remaining}, {rate_fmt}{postfix}]",
             )
             pr(0, desc=self._get_translation("Подготовка..."))
-            selected_image = image if scale_selector["scale"] else image2
-            if scale_selector["scale"]:
-                if (
-                    image.get("background") is None
-                    and image.get("composite") is None
-                    and not image.get("layers")
-                ):
-                    gr.Warning(
-                        self._get_translation("Ошибка: изображение отсутствует...")
-                    )
-                    return self._create_error_return()
-            elif image2 is None:
+            selected_image = image2
+
+            if selected_image is None:
                 gr.Warning(self._get_translation("Ошибка: изображение отсутствует..."))
                 return self._create_error_return()
 
             image, orig_image, gray_image, scale, scale_factor_glob = (
                 self.preprocessor.preprocess_image(
                     image=selected_image,
+                    scale=scale,
                     scale_selector=scale_selector,
                     solution=solution,
                     request=request,
@@ -244,6 +242,11 @@ class ParticleAnalyzer:
                 return self._create_error_return()
 
             output_image = cv2.cvtColor(output_image, cv2.COLOR_BGR2RGB)
+            if scale_selector["scale"]:
+                output_image = point_manager.draw_scale_on_image(
+                    output_image, scale_factor_glob, scale, *points_scale
+                )
+
             df = pd.DataFrame(particle_data)
             points_df = pd.DataFrame(df["points"])
             df = df.drop(columns=["points"])
@@ -260,47 +263,13 @@ class ParticleAnalyzer:
             )
             stats_df = builder.build_stats_table()
 
-            d_max_max = round(
-                stats_df.data.iloc[1, 3] + stats_df.data.iloc[0, 3] * 0.01,
-                config["round_value"],
-            )
-            d_max_min = round(stats_df.data.iloc[1, 4], config["round_value"])
-            d_min_max = round(
-                stats_df.data.iloc[2, 3] + stats_df.data.iloc[1, 3] * 0.01,
-                config["round_value"],
-            )
-            d_min_min = round(stats_df.data.iloc[2, 4], config["round_value"])
-            theta_max_max = round(
-                stats_df.data.iloc[4, 3] + stats_df.data.iloc[4, 3] * 0.01,
-                config["round_value"],
-            )
-            theta_max_min = round(stats_df.data.iloc[4, 4], config["round_value"])
-            theta_min_max = round(
-                stats_df.data.iloc[5, 3] + stats_df.data.iloc[5, 3] * 0.01,
-                config["round_value"],
-            )
-            theta_min_min = round(stats_df.data.iloc[5, 4], config["round_value"])
-            S_max = round(
-                stats_df.data.iloc[6, 3] + stats_df.data.iloc[6, 3] * 0.01,
-                config["round_value"],
-            )
-            S_min = round(stats_df.data.iloc[6, 4], config["round_value"])
-            P_max = round(
-                stats_df.data.iloc[7, 3] + stats_df.data.iloc[7, 3] * 0.01,
-                config["round_value"],
-            )
-            P_min = round(stats_df.data.iloc[7, 4], config["round_value"])
-            I_max = round(
-                stats_df.data.iloc[9, 3] + stats_df.data.iloc[9, 3] * 0.01,
-                config["round_value"],
-            )
-            I_min = round(stats_df.data.iloc[9, 4], config["round_value"])
+            limits = self.calculate_limits(df, config["round_value"])
 
             pbar.update(1)
 
             pbar.set_description(self._get_translation("Построение графиков..."))
             pr(0.9, desc=self._get_translation("Построение графиков..."))
-            fig = builder.build_distribution_fig(image)
+            fig, vector_fig = builder.build_distribution_fig(image)
             pbar.update(1)
             pr(1, desc=self._get_translation("Готово!"))
             return (
@@ -308,49 +277,55 @@ class ParticleAnalyzer:
                 df,
                 points_df,
                 fig,
+                vector_fig,
                 stats_df,
                 gr.update(visible=api_key),
                 gr.update(visible=True),
                 gr.update(
-                    minimum=d_max_min,
-                    maximum=d_max_max,
-                    value=(d_max_min, d_max_max),
-                    step=d_max_max * 0.01,
+                    minimum=limits["d_max_min"],
+                    maximum=limits["d_max_max"],
+                    value=(limits["d_max_min"], limits["d_max_max"]),
+                    step=limits["d_max_max"] * 0.01,
                     label=f"Dₘₐₓ [{self._get_translation(scale_selector['unit'])}]",
                 ),
                 gr.update(
-                    minimum=d_min_min,
-                    maximum=d_min_max,
-                    value=(d_min_min, d_min_max),
-                    step=d_min_max * 0.01,
+                    minimum=limits["d_min_min"],
+                    maximum=limits["d_min_max"],
+                    value=(limits["d_min_min"], limits["d_min_max"]),
+                    step=limits["d_min_max"] * 0.01,
                     label=f"Dₘᵢₙ [{self._get_translation(scale_selector['unit'])}]",
                 ),
                 gr.update(
-                    minimum=theta_max_min,
-                    maximum=theta_max_max,
-                    value=(theta_max_min, theta_max_max),
+                    minimum=limits["theta_max_min"],
+                    maximum=limits["theta_max_max"],
+                    value=(limits["theta_max_min"], limits["theta_max_max"]),
                 ),
                 gr.update(
-                    minimum=theta_min_min,
-                    maximum=theta_min_max,
-                    value=(theta_min_min, theta_min_max),
+                    minimum=limits["theta_min_min"],
+                    maximum=limits["theta_min_max"],
+                    value=(limits["theta_min_min"], limits["theta_min_max"]),
                 ),
                 gr.update(minimum=0, maximum=1, value=(0, 1)),
                 gr.update(
-                    minimum=S_min,
-                    maximum=S_max,
-                    value=(S_min, S_max),
-                    step=S_max * 0.01,
+                    minimum=limits["S_min"],
+                    maximum=limits["S_max"],
+                    value=(limits["S_min"], limits["S_max"]),
+                    step=limits["S_max"] * 0.01,
                     label=f"S [{self._get_translation(scale_selector['unit'])}²]",
                 ),
                 gr.update(
-                    minimum=P_min,
-                    maximum=P_max,
-                    value=(P_min, P_max),
-                    step=P_max * 0.01,
+                    minimum=limits["P_min"],
+                    maximum=limits["P_max"],
+                    value=(limits["P_min"], limits["P_max"]),
+                    step=limits["P_max"] * 0.01,
                     label=f"P [{self._get_translation(scale_selector['unit'])}]",
                 ),
-                gr.update(minimum=I_min, maximum=I_max, value=(I_min, I_max)),
+                gr.update(
+                    minimum=limits["I_min"],
+                    maximum=limits["I_max"],
+                    value=(limits["I_min"], limits["I_max"]),
+                ),
+                gr.update(visible=True),
                 gr.update(visible=True),
             )
         except Exception as e:
@@ -795,6 +770,46 @@ class ParticleAnalyzer:
 
         return (b, g, r)
 
+    @staticmethod
+    def calculate_limits(df: pd.DataFrame, round_value: int) -> Dict[str, float]:
+
+        results = {}
+
+        results["d_max_max"] = round(
+            df.iloc[:, 2].max() + df.iloc[:, 2].max() * 0.01, round_value
+        )
+        results["d_max_min"] = round(df.iloc[:, 2].min(), round_value)
+        results["d_min_max"] = round(
+            df.iloc[:, 3].max() + df.iloc[:, 3].max() * 0.01, round_value
+        )
+        results["d_min_min"] = round(df.iloc[:, 3].min(), round_value)
+
+        results["theta_max_max"] = round(
+            df.iloc[:, 5].max() + df.iloc[:, 5].max() * 0.01, round_value
+        )
+        results["theta_max_min"] = round(df.iloc[:, 5].min(), round_value)
+        results["theta_min_max"] = round(
+            df.iloc[:, 6].max() + df.iloc[:, 6].max() * 0.01, round_value
+        )
+        results["theta_min_min"] = round(df.iloc[:, 6].min(), round_value)
+
+        results["S_max"] = round(
+            df.iloc[:, 7].max() + df.iloc[:, 7].max() * 0.01, round_value
+        )
+        results["S_min"] = round(df.iloc[:, 7].min(), round_value)
+
+        results["P_max"] = round(
+            df.iloc[:, 8].max() + df.iloc[:, 8].max() * 0.01, round_value
+        )
+        results["P_min"] = round(df.iloc[:, 8].min(), round_value)
+
+        results["I_max"] = round(
+            df.iloc[:, 10].max() + df.iloc[:, 10].max() * 0.01, round_value
+        )
+        results["I_min"] = round(df.iloc[:, 10].min(), round_value)
+
+        return results
+
     def _cleanup(self, pbar: Optional[tqdm] = None):
         """Очистка ресурсов"""
         if pbar:
