@@ -4,7 +4,8 @@ from ultralytics import YOLO
 
 class YOLOLoader:
     MODEL_MAPPING = {
-        "Yolo11 (dataset 7)": "Yolo11_d7.pt",
+        "Yolo11 (dataset 8)": "Yolo11_d8_batch64.pt",
+        "Yolo12 (dataset 8)": "Yolo12_d8_batch64.pt",
     }
 
     def __init__(self):
