@@ -26,6 +26,7 @@ translations = {
         "Достигнут предел количества обнаружений. Увеличьте максимальное количество обнаружений в настройках.": "Достигнут предел количества обнаружений. Увеличьте максимальное количество обнаружений в настройках.",
         "Обработка частиц...": "Обработка частиц...",
         "мкм": "мкм",
+        "нм": "нм",
         "пикс": "пикс",
         "ед.": "ед.",
         "Диаметр": "Диаметр",
@@ -137,7 +138,20 @@ translations = {
         "Тип заливки": "Тип заливки",
         "Цвет заливки": "Цвет заливки",
         "Прозрачность заливки": "Прозрачность заливки",
-        "Удалить частицу": "Удалить частицу",
+        "Удалить частицы": "Удалить частицы",
+        "Сбросить таблицу": "Сбросить таблицу",
+        "Загрузить изображение СЭМ": "Загрузить изображение СЭМ",
+        "Статус калибровки масштаба": "Статус калибровки масштаба",
+        "Выберите две крайние точки на шкале": "Выберите две крайние точки на шкале",
+        "Расстояние равно": "Расстояние равно",
+        "пикселей": "пикселей",
+        "Выбрано точек": "Выбрано точек",
+        "Ориентация": "Ориентация",
+        "Количество обнаружений": "Количество обнаружений",
+        "Настройки обнаружения": "Настройки обнаружения",
+        "Обработка с разбиением (SAHI)": "Обработка с разбиением (SAHI)",
+        "Основные параметры": "Основные параметры",
+        "Параметры визуализации": "Параметры визуализации",
     },
     "en": {
         "Подготовка...": "Initializing...",
@@ -153,6 +167,7 @@ translations = {
         "Обработка частиц...": "Processing particles...",
         "ед.": "units",
         "мкм": "µm",
+        "нм": "nm",
         "пикс": "px",
         "Диаметр": "Diameter",
         "Средний диаметр": "Average diameter",
@@ -263,7 +278,20 @@ translations = {
         "Тип заливки": "Fill Type",
         "Цвет заливки": "Fill Color",
         "Прозрачность заливки": "Fill Transparency",
-        "Удалить частицу": "Remove particle",
+        "Удалить частицы": "Remove particles",
+        "Сбросить таблицу": "Reset table",
+        "Загрузить изображение СЭМ": "Upload SEM image",
+        "Статус калибровки масштаба": "Scale calibration status",
+        "Выберите две крайние точки на шкале": "Select the two extreme points of the scale.",
+        "Расстояние равно": "Distance is",
+        "пикселей": "pixels",
+        "Выбрано точек": "Points selected",
+        "Ориентация": "Orientation",
+        "Количество обнаружений": "Number of detections",
+        "Настройки обнаружения": "Discovery Settings",
+        "Обработка с разбиением (SAHI)": "Split processing (SAHI)",
+        "Основные параметры": "Basic parameters",
+        "Параметры визуализации": "Visualization Parameters",
     },
     "zh-cn": {
         "Подготовка...": "初始化中...",
@@ -278,6 +306,7 @@ translations = {
         "Достигнут предел количества обнаружений. Увеличьте максимальное количество обнаружений в настройках.": "达到检测数量上限。请在设置中增加最大检测数量",
         "Обработка частиц...": "正在处理粒子...",
         "мкм": "微米",
+        "нм": "纳米",
         "пикс": "像素",
         "ед.": "单位",
         "Диаметр": "直径",
@@ -389,7 +418,20 @@ translations = {
         "Тип заливки": "填充类型",
         "Цвет заливки": "填充颜色",
         "Прозрачность заливки": "填充透明度",
-        "Удалить частицу": "去除颗粒",
+        "Удалить частицы": "去除颗粒",
+        "Сбросить таблицу": "重置表",
+        "Загрузить изображение СЭМ": "上传扫描电镜图像",
+        "Статус калибровки масштаба": "秤校准状态",
+        "Выберите две крайние точки на шкале": "选择尺度的两个极值点。",
+        "Расстояние равно": "距离",
+        "пикселей": "像素",
+        "Выбрано точек": "已选点",
+        "Ориентация": "方向",
+        "Количество обнаружений": "检测次数",
+        "Настройки обнаружения": "发现设置",
+        "Обработка с разбиением (SAHI)": "分区处理（SAHI）",
+        "Основные параметры": "基本参数",
+        "Параметры визуализации": "渲染选项",
     },
     "zh-tw": {
         "Подготовка...": "初始化中...",
@@ -404,6 +446,7 @@ translations = {
         "Достигнут предел количества обнаружений. Увеличьте максимальное количество обнаружений в настройках.": "達到檢測數量上限。請在設定中增加最大檢測數量",
         "Обработка частиц...": "正在處理粒子...",
         "мкм": "微米",
+        "нм": "奈米",
         "пикс": "像素",
         "ед.": "單位",
         "Диаметр": "直徑",
@@ -522,8 +565,20 @@ translations = {
         "Включить заливку?": "啟用填充？",
         "Тип заливки": "填滿類型",
         "Цвет заливки": "填滿顏色",
-        "Прозрачность заливки": "填滿透明度",
-        "Удалить частицу": "去除顆粒",
+        "Удалить частицы": "去除顆粒",
+        "Сбросить таблицу": "重設表",
+        "Загрузить изображение СЭМ": "上傳掃描電子顯微鏡影像",
+        "Статус калибровки масштаба": "秤校準狀態",
+        "Выберите две крайние точки на шкале": "選擇尺度的兩個極值點。",
+        "Расстояние равно": "距離",
+        "пикселей": "像素",
+        "Выбрано точек": "已選點",
+        "Ориентация": "方向",
+        "Количество обнаружений": "檢測次數",
+        "Настройки обнаружения": "發現設定",
+        "Обработка с разбиением (SAHI)": "分區處理（SAHI）",
+        "Основные параметры": "基本參數",
+        "Параметры визуализации": "渲染選項",
     },
 }
 
