@@ -17,12 +17,15 @@ from particleanalyzer.core.utils import (
     statistic_an,
     select_particle_from_image,
     particle_removal,
+    reset_selection,
+    handle_file_upload,
 )
 from particleanalyzer.core.about import about_ru
 from particleanalyzer.core.parameter_information import reference_ru
 from particleanalyzer.core.ui_styles import css, custom_head
 from particleanalyzer.core.languages import i18n
 from particleanalyzer.core.LLMAnalysis import LLMAnalysis
+from particleanalyzer.core.PointManager import PointManager
 from .YOLOLoader import YOLOLoader
 
 try:
@@ -45,6 +48,7 @@ def assets_path(name: str):
     return os.path.join(os.path.dirname(__file__), "..", "assets", name)
 
 
+point_manager = PointManager()
 analyzer = ParticleAnalyzer()
 
 my_theme = gr.Theme.load(f"{assets_path('')}/themes/theme_schema@0.0.1.json").set(
@@ -69,18 +73,23 @@ def create_interface(api_key):
     with demo:
         api_key = gr.State(True if api_key else False)
         points_df = gr.State()
+        scale = gr.State()
+        points_scale = gr.State()
+
         with gr.Column(elem_id="app-container"):
             with gr.Row(equal_height=True, elem_id="gr-head"):
                 gr.HTML(
                     f"""
                     <div style="display: flex; justify-content: space-between; align-items: center;">
                         <div style="display: inline-block; margin-left: 7px; overflow: hidden;">
-                          <img 
-                            src="https://rybakov-k.ru/assets/icon/Logo2.png" 
-                            alt="ParticleAnalyzer" 
-                            style="max-height: 50px; width: auto; height: auto;"
-                            class="logo-image"
-                          >
+                            <a href="https://particleanalyzer.ru" target="_blank">
+                              <img 
+                                src="https://rybakov-k.ru/assets/icon/Logo2.png" 
+                                alt="ParticleAnalyzer" 
+                                style="max-height: 50px; width: auto; height: auto;"
+                                class="logo-image"
+                              >
+                            </a>
                         </div>
 
                         <div style="display: flex; align-items: center; gap: 10px;">
@@ -131,103 +140,137 @@ def create_interface(api_key):
                                     value=list(analyzer.SCALE_OPTIONS.keys())[0],
                                     label=i18n("Режим масштабирования"),
                                     elem_id="scale-selector",
+                                    elem_classes="styled-dropdown",
                                 )
-                            with gr.Row(
-                                visible=False, variant="default"
-                            ) as row_instruction:
-                                with gr.Accordion(
-                                    i18n("Как задать масштаб?"), open=False
-                                ):
-                                    gr.Video(
-                                        f'{assets_path("")}/instruction.mp4',
-                                        label=i18n("Видео инструкция"),
-                                    )
-                            with gr.Row(equal_height=True):
-                                with gr.Column(visible=False) as Paint_row:
-                                    im = gr.Paint(
-                                        label=i18n("Изображение СЭМ"),
-                                        type="numpy",
-                                        canvas_size=(600, 600),
-                                        sources=["upload"],
-                                        brush=gr.Brush(
-                                            color_mode="fixed",
-                                            default_color="green",
-                                            colors=["green"],
-                                        ),
-                                        transforms="crop",
-                                        layers=False,
-                                        eraser=gr.Eraser(default_size=200),
-                                        elem_id="in-image-paint",
-                                        image_mode="RGB",
-                                    )
-                                with gr.Column() as Image_row:
-                                    in_image = gr.Image(
-                                        sources=["upload"],
-                                        label=i18n("Изображение СЭМ"),
-                                        elem_id="in-image",
-                                    )
-
-                                with gr.Column():
-                                    output_image = gr.Image(
-                                        label=i18n("Результат сегментации"),
-                                        elem_id="output-image",
-                                    )
-                            with gr.Row(visible=False) as output_table_image2_row:
-                                with gr.Column():
-                                    output_table_image2 = gr.Dataframe(
-                                        value=empty_df_ParticleCharacteristics,
-                                        label=i18n("Характеристики частицы"),
-                                        interactive=True,
-                                        elem_id="dataframe-table",
-                                        show_copy_button=True,
-                                    )
-                                    delete_row = gr.Button(
-                                        value=i18n("Удалить частицу"),
-                                        icon="https://rybakov-k.ru/assets/icon/incorrect.png",
-                                        elem_id="delete-row-btn",
-                                        elem_classes="custom-btn btn-delete-row",
-                                    )
-
-                            with gr.Row(visible=False) as scale_input_row:
-                                scale_input = gr.Number(
-                                    label="Длина шкалы в мкм",
-                                    value=1.0,
-                                    elem_id="scale-input",
+                            with gr.Row() as row_image_file:
+                                image_file = gr.File(
+                                    label=i18n("Загрузить изображение СЭМ"),
+                                    file_types=[
+                                        ".tif",
+                                        ".tiff",
+                                        ".png",
+                                        ".jpg",
+                                        ".jpeg",
+                                        ".bmp",
+                                        ".webp",
+                                    ],
+                                    file_count="single",
+                                    elem_id="image-file",
+                                    height=450,
                                 )
+                            with gr.Row(visible=False) as row_analysis:
+                                with gr.Column():
+                                    with gr.Row(
+                                        visible=False, variant="default"
+                                    ) as row_instruction:
+                                        with gr.Accordion(
+                                            i18n("Как задать масштаб?"),
+                                            open=False,
+                                            elem_id="instruction",
+                                        ):
+                                            gr.Video(
+                                                f'{assets_path("")}/instruction.mp4',
+                                                label=i18n("Видео инструкция"),
+                                            )
+                                    with gr.Row(equal_height=True):
+                                        with gr.Column():
+                                            in_image = gr.Image(
+                                                sources=[],
+                                                label=i18n("Изображение СЭМ"),
+                                                elem_id="in-image",
+                                                type="numpy",
+                                            )
 
-                            with gr.Row(elem_id="button-row"):
-                                with gr.Column(min_width=140):
-                                    process_button = gr.Button(
-                                        value=i18n("Анализировать"),
-                                        icon="https://rybakov-k.ru/assets/icon/icons8-химия-50.png",
-                                        elem_id="process-button",
-                                        elem_classes="custom-btn btn-analyze",
-                                    )
-                                with gr.Column(min_width=140):
-                                    clear_button = gr.Button(
-                                        value=i18n("Очистить"),
-                                        icon="https://rybakov-k.ru/assets/icon/icons8-метла-50.png",
-                                        elem_id="clear-btn",
-                                        elem_classes="custom-btn btn-clear",
-                                    )
+                                        with gr.Column(
+                                            visible=False
+                                        ) as output_image_row:
+                                            output_image = gr.Image(
+                                                label=i18n("Результат сегментации"),
+                                                elem_id="output-image",
+                                            )
+                                    with gr.Row(
+                                        visible=False, elem_id="output-table-image2-row"
+                                    ) as output_table_image2_row:
+                                        with gr.Column():
+                                            output_table_image2 = gr.Dataframe(
+                                                value=empty_df_ParticleCharacteristics,
+                                                label=i18n("Характеристики частицы"),
+                                                interactive=True,
+                                                elem_id="dataframe-table",
+                                                show_copy_button=True,
+                                            )
+                                    with gr.Row(
+                                        visible=False,
+                                        elem_id="reset-delete-buttons-row",
+                                    ) as reset_delete_buttons_row:
+                                        with gr.Column():
+                                            reset_df = gr.Button(
+                                                value=i18n("Сбросить таблицу"),
+                                                icon="https://rybakov-k.ru/assets/icon/reset-14414.png",
+                                                elem_id="reset-row-btn",
+                                                elem_classes="custom-btn btn-reset-row",
+                                            )
+                                        with gr.Column():
+                                            delete_row = gr.Button(
+                                                value=i18n("Удалить частицы"),
+                                                icon="https://rybakov-k.ru/assets/icon/incorrect.png",
+                                                elem_id="delete-row-btn",
+                                                elem_classes="custom-btn btn-delete-row",
+                                            )
 
-                    with gr.Row(elem_id="example-row") as in_image_example_row:
+                                    with gr.Row(
+                                        visible=False, elem_id="scale-input-row"
+                                    ) as scale_input_row:
+                                        scale_input_status = gr.Textbox(
+                                            value=i18n(
+                                                "Выберите две крайние точки на шкале"
+                                            ),
+                                            label=i18n("Статус калибровки масштаба"),
+                                        )
+                                        scale_input = gr.Number(
+                                            label="Длина шкалы в мкм",
+                                            value=1.0,
+                                            elem_id="scale-input",
+                                        )
+
+                                    with gr.Row(elem_id="button-row"):
+                                        with gr.Column(min_width=140):
+                                            process_button = gr.Button(
+                                                value=i18n("Анализировать"),
+                                                icon="https://rybakov-k.ru/assets/icon/icons8-химия-50-white.png",
+                                                elem_id="process-button",
+                                                elem_classes="custom-btn btn-analyze",
+                                            )
+                                        with gr.Column(min_width=140):
+                                            clear_button = gr.Button(
+                                                value=i18n("Очистить"),
+                                                icon="https://rybakov-k.ru/assets/icon/icons8-метла-50-white.png",
+                                                elem_id="clear-btn",
+                                                elem_classes="custom-btn btn-clear",
+                                            )
+
+                    with gr.Row(elem_id="example-row"):
                         gr.Examples(
                             examples=[
-                                "https://raw.githubusercontent.com/rybakov-ks/ParticleAnalyzer/main/example/100%20r-.jpg",
-                                "https://raw.githubusercontent.com/rybakov-ks/ParticleAnalyzer/main/example/Tv30_1.webp",
-                                "https://raw.githubusercontent.com/rybakov-ks/ParticleAnalyzer/main/example/A02-1.webp",
-                                "https://raw.githubusercontent.com/rybakov-ks/ParticleAnalyzer/main/example/Rec-Cu-Ni-Powder_250x_5_SE_V1_png.jpg",
-                                "https://raw.githubusercontent.com/rybakov-ks/ParticleAnalyzer/main/example/Resolution%20in%20SEM%201.jpg",
-                                "https://raw.githubusercontent.com/rybakov-ks/ParticleAnalyzer/main/example/image_c_01.webp",
+                                "https://raw.githubusercontent.com/rybakov-ks/ParticleAnalyzer/refs/heads/main/example/Cathode_LiCoVO4.jpg",
+                                "https://raw.githubusercontent.com/rybakov-ks/ParticleAnalyzer/refs/heads/main/example/Chitosan.webp",
+                                "https://raw.githubusercontent.com/rybakov-ks/ParticleAnalyzer/refs/heads/main/example/Silicon_oxide.webp",
+                                "https://raw.githubusercontent.com/rybakov-ks/ParticleAnalyzer/refs/heads/main/example/Gold_on_carbon.jpg",
+                                "https://raw.githubusercontent.com/rybakov-ks/ParticleAnalyzer/refs/heads/main/example/Colloidal_silver.webp",
                             ],
-                            inputs=in_image,
+                            example_labels=[
+                                "Cathode material LiCoVO₄",
+                                "Chitosan nanoparticles",
+                                "Silicon oxide",
+                                "Gold on carbon",
+                                "Colloidal silver",
+                            ],
+                            inputs=[image_file],
                             label=i18n("Примеры"),
                             elem_id="examples_images",
                         )
 
                     with gr.Row(visible=False, min_height=650) as results_row:
-
                         with gr.Column():
                             gr.HTML(
                                 f"""
@@ -265,8 +308,14 @@ def create_interface(api_key):
                                         output_plot = gr.Plot(
                                             label=i18n("Графики распределения")
                                         )
+                                with gr.Tab(i18n("Ориентация"), id=3):
+                                    with gr.Row():
+                                        vector_field = gr.Plot(
+                                            label=i18n("Векторное поле ориентации"),
+                                            show_label=False,
+                                        )
                                 with gr.Tab(
-                                    i18n("ИИ-анализ"), id=3, visible=False
+                                    i18n("ИИ-анализ"), id=4, visible=False
                                 ) as chatbot_row:
                                     with gr.Group():
                                         with gr.Column(scale=1):
@@ -292,25 +341,25 @@ def create_interface(api_key):
                                         with gr.Column(min_width=140):
                                             llm_run = gr.Button(
                                                 value=i18n("Запустить ИИ-анализ"),
-                                                icon="https://rybakov-k.ru/assets/icon/ai.png",
+                                                icon="https://rybakov-k.ru/assets/icon/ai-white.png",
                                                 elem_id="ai-run-btn",
                                                 elem_classes="custom-btn btn-ai-run",
                                             )
                                         with gr.Column(min_width=140):
                                             cancel_llm_button = gr.Button(
                                                 value=i18n("Отменить"),
-                                                icon="https://rybakov-k.ru/assets/icon/incorrect.png",
+                                                icon="https://rybakov-k.ru/assets/icon/incorrect-white.png",
                                                 elem_id="ai-cancel-btn",
                                                 elem_classes="custom-btn btn-ai-cancel",
                                             )
 
-                                with gr.Tab(i18n("Файлы"), id=4):
+                                with gr.Tab(i18n("Файлы"), id=5):
                                     with gr.Row():
                                         download_output = gr.Files(
                                             label=i18n("Файлы для скачивания")
                                         )
                                 with gr.Tab(
-                                    i18n("Оценить результаты"), id=5
+                                    i18n("Оценить результаты"), id=6
                                 ) as question_row:
                                     with gr.Row():
                                         gr.Markdown(
@@ -322,20 +371,23 @@ def create_interface(api_key):
                                         with gr.Column(min_width=140):
                                             yes_button = gr.Button(
                                                 value=i18n("Да"),
-                                                icon="https://rybakov-k.ru/assets/icon/like.png",
+                                                icon="https://rybakov-k.ru/assets/icon/like-white.png",
                                                 elem_id="yes-btn",
                                                 elem_classes="custom-btn btn-yes",
                                             )
                                         with gr.Column(min_width=140):
                                             no_button = gr.Button(
                                                 value=i18n("Нет"),
-                                                icon="https://rybakov-k.ru/assets/icon/dislike.png",
+                                                icon="https://rybakov-k.ru/assets/icon/dislike-white.png",
                                                 elem_id="no-btn",
                                                 elem_classes="custom-btn btn-no",
                                             )
 
                 with gr.Tab(i18n("Настройки"), elem_id="setting"):
                     with gr.Group(elem_id="model-setting"):
+                        gr.Markdown(
+                            f"<h3 style='margin-left: 7px;'><i class='fas fa-search'></i> {i18n('Настройки обнаружения')}</h3>"
+                        )
                         with gr.Row():
                             model_change = gr.Dropdown(
                                 get_available_models(),
@@ -358,6 +410,9 @@ def create_interface(api_key):
                                 label=i18n("Порог перекрытия (IoU)"),
                             )
                     with gr.Group(elem_id="sahi-setting"):
+                        gr.Markdown(
+                            f"<h3 style='margin-left: 7px;'><i class='fas fa-puzzle-piece'></i> {i18n('Обработка с разбиением (SAHI)')}</h3>"
+                        )
                         with gr.Row():
                             sahi_mode = gr.Checkbox(
                                 label=i18n("Включить"),
@@ -387,80 +442,90 @@ def create_interface(api_key):
                                 step=0.01,
                                 label=i18n("Перекрытие по ширине"),
                             )
-                    with gr.Row(
-                        equal_height=True, elem_id="solution-segment-mode-setting"
-                    ) as solution_and_segment_mode_row:
-                        with gr.Column():
-                            solution = gr.Radio(
-                                ("Original", "640x640", "1024x1024"),
-                                value="1024x1024",
-                                label=i18n("Разрешение изображения"),
-                            )
-                        with gr.Column():
-                            number_detections = gr.Slider(
-                                minimum=1,
-                                maximum=10000,
-                                value=1000,
-                                step=100,
-                                label=i18n("Количество обнаружений"),
-                                elem_id="number-detections",
-                            )
-                    with gr.Row(visible=False):
-                        round_value = gr.Dropdown(
-                            [0, 1, 2, 3, 4, 5, 6],
-                            value=4,
-                            label=i18n("Округлять результаты до"),
+                    with gr.Group():
+                        gr.Markdown(
+                            f"<h3 style='margin-left: 7px;'><i class='fas fa-sliders-h'></i> {i18n('Основные параметры')}</h3>"
                         )
-                    with gr.Row(equal_height=True, elem_id="bins-feret-diametr"):
-                        with gr.Column(scale=1):
-                            number_of_bins = gr.Slider(
-                                minimum=0.0,
-                                maximum=100,
-                                value=20,
-                                step=1,
-                                label=i18n("Интервалов на гистограмме"),
-                            )
-                        with gr.Column(scale=1):
-                            show_Feret_diametr = gr.Checkbox(
-                                label=i18n("Включить"),
-                                info=i18n("Включить отображение диаметров Ферета?"),
-                            )
-                        with gr.Column():
-                            show_polylines = gr.Checkbox(
-                                value=True,
-                                label=i18n("Включить"),
-                                info=i18n("Включить контур?"),
-                            )
-                        with gr.Column():
-                            outline_color = gr.ColorPicker(
-                                value="rgb(0, 255, 0, 1)", label=i18n("Цвет контура")
-                            )
-                        with gr.Column(min_width=100):
-                            show_fillPoly = gr.Checkbox(
-                                label=i18n("Включить"),
-                                info=i18n("Включить заливку?"),
-                            )
-                        with gr.Column(min_width=250):
-                            fill_type_color = gr.Radio(
-                                ("Random", "Permanent"),
-                                value="Random",
-                                label=i18n("Тип заливки"),
-                            )
-                        with gr.Column(min_width=300):
-                            fill_color = gr.ColorPicker(
-                                value="rgb(0, 255, 0, 1)", label=i18n("Цвет заливки")
-                            )
-                        with gr.Column():
-                            fill_alpha = gr.Slider(
-                                minimum=0,
-                                maximum=1,
-                                value=0.3,
-                                step=0.01,
-                                label=i18n("Прозрачность заливки"),
+                        with gr.Row(equal_height=True) as solution_and_segment_mode_row:
+                            with gr.Column():
+                                solution = gr.Radio(
+                                    ("Original", "640x640", "1024x1024"),
+                                    value="1024x1024",
+                                    label=i18n("Разрешение изображения"),
+                                    elem_id="solution-setting",
+                                )
+                            with gr.Column():
+                                number_detections = gr.Slider(
+                                    minimum=1,
+                                    maximum=10000,
+                                    value=1000,
+                                    step=100,
+                                    label=i18n("Количество обнаружений"),
+                                    elem_id="number-detections",
+                                )
+                        with gr.Row(visible=False):
+                            round_value = gr.Dropdown(
+                                [0, 1, 2, 3, 4, 5, 6],
+                                value=4,
+                                label=i18n("Округлять результаты до"),
                             )
+                        with gr.Row(equal_height=True, elem_id="bins-feret-diametr"):
+                            with gr.Column(scale=1):
+                                number_of_bins = gr.Slider(
+                                    minimum=0.0,
+                                    maximum=100,
+                                    value=20,
+                                    step=1,
+                                    label=i18n("Интервалов на гистограмме"),
+                                )
+                            with gr.Column(scale=1):
+                                show_Feret_diametr = gr.Checkbox(
+                                    label=i18n("Включить"),
+                                    info=i18n("Включить отображение диаметров Ферета?"),
+                                )
+                    with gr.Group(elem_id="visualization-settings"):
+                        gr.Markdown(
+                            f"<h3 style='margin-left: 7px;'><i class='fas fa-paint-brush'></i> {i18n('Параметры визуализации')}</h3>"
+                        )
+                        with gr.Row(equal_height=True):
+                            with gr.Column():
+                                show_polylines = gr.Checkbox(
+                                    value=True,
+                                    label=i18n("Включить"),
+                                    info=i18n("Включить контур?"),
+                                )
+                            with gr.Column():
+                                outline_color = gr.ColorPicker(
+                                    value="rgb(0, 255, 0, 1)",
+                                    label=i18n("Цвет контура"),
+                                )
+                            with gr.Column(min_width=100):
+                                show_fillPoly = gr.Checkbox(
+                                    label=i18n("Включить"),
+                                    info=i18n("Включить заливку?"),
+                                )
+                            with gr.Column(min_width=250):
+                                fill_type_color = gr.Radio(
+                                    ("Random", "Permanent"),
+                                    value="Random",
+                                    label=i18n("Тип заливки"),
+                                )
+                            with gr.Column(min_width=300):
+                                fill_color = gr.ColorPicker(
+                                    value="rgb(0, 255, 0, 1)",
+                                    label=i18n("Цвет заливки"),
+                                )
+                            with gr.Column():
+                                fill_alpha = gr.Slider(
+                                    minimum=0,
+                                    maximum=1,
+                                    value=0.3,
+                                    step=0.01,
+                                    label=i18n("Прозрачность заливки"),
+                                )
                 with gr.Tab(i18n("О программе")):
                     gr.HTML(i18n(about_ru))
-        with gr.Row(visible=False) as slider:
+        with gr.Row(visible=False) as sidebar:
             with gr.Sidebar(width=400):
                 with gr.Row():
                     gr.HTML(
@@ -519,11 +584,25 @@ def create_interface(api_key):
                 # </button>
                 # """
                 # )
+
+        image_file.change(
+            fn=handle_file_upload,
+            inputs=[image_file, scale_selector],
+            outputs=[in_image, row_image_file, row_analysis],
+        )
+
+        in_image.select(
+            fn=point_manager.handle_select,
+            inputs=scale_selector,
+            outputs=[scale_input_status, scale, points_scale],
+        )
+
         analyze = process_button.click(
             fn=analyzer.analyze_image,
             inputs=[
-                im,
                 in_image,
+                scale,
+                points_scale,
                 scale_input,
                 confidence_threshold,
                 scale_selector,
@@ -552,6 +631,7 @@ def create_interface(api_key):
                 output_table,
                 points_df,
                 output_plot,
+                vector_field,
                 output_table2,
                 chatbot_row,
                 results_row,
@@ -563,22 +643,48 @@ def create_interface(api_key):
                 S_slider,
                 P_slider,
                 I_slider,
-                slider,
+                sidebar,
+                output_image_row,
             ],
-            show_progress_on=output_image,
+            show_progress_on=in_image,
         )
 
         output_image.select(
             select_particle_from_image,
             inputs=[points_df, output_table],
-            outputs=[output_table_image2, output_table_image2_row],
+            outputs=[
+                output_table_image2,
+                output_table_image2_row,
+                reset_delete_buttons_row,
+            ],
         )
 
         process_button.click(translate_chatbot, None, chatbot)
         delete_row.click(
             particle_removal,
-            inputs=[output_table_image2, points_df, output_table],
-            outputs=[output_table_image2_row, points_df, output_table],
+            inputs=[
+                output_table_image2,
+                points_df,
+                output_table,
+                round_value,
+                scale_selector,
+            ],
+            outputs=[
+                output_table_image2_row,
+                reset_delete_buttons_row,
+                points_df,
+                output_table,
+                d_max_slider,
+                d_min_slider,
+                theta_max_slider,
+                theta_min_slider,
+                e_slider,
+                S_slider,
+                P_slider,
+                I_slider,
+            ],
+            show_progress="hide",
+            show_progress_on=[points_df],
         ).success(
             fn=statistic_an,
             inputs=[
@@ -595,7 +701,6 @@ def create_interface(api_key):
                 S_slider,
                 P_slider,
                 I_slider,
-                im,
                 in_image,
                 solution,
                 sahi_mode,
@@ -606,7 +711,17 @@ def create_interface(api_key):
                 fill_color,
                 fill_alpha,
             ],
-            outputs=[output_table2, output_plot, output_image],
+            outputs=[output_image, output_table2, output_plot, vector_field],
+        )
+        gr.on(
+            triggers=[reset_df.click, process_button.click],
+            fn=reset_selection,
+            inputs=output_table_image2,
+            outputs=[
+                output_table_image2,
+                output_table_image2_row,
+                reset_delete_buttons_row,
+            ],
         )
         gr.on(
             triggers=[
@@ -634,7 +749,6 @@ def create_interface(api_key):
                 S_slider,
                 P_slider,
                 I_slider,
-                im,
                 in_image,
                 solution,
                 sahi_mode,
@@ -645,7 +759,7 @@ def create_interface(api_key):
                 fill_color,
                 fill_alpha,
             ],
-            outputs=[output_table2, output_plot, output_image],
+            outputs=[output_image, output_table2, output_plot, vector_field],
         )
 
         llm_start = llm_run.click(
@@ -660,10 +774,7 @@ def create_interface(api_key):
             inputs=scale_selector,
             outputs=[
                 scale_input_row,
-                Paint_row,
-                Image_row,
                 output_table,
-                in_image_example_row,
                 output_table_image2,
                 row_instruction,
             ],
@@ -684,34 +795,43 @@ def create_interface(api_key):
         )
 
         gr.on(
-            triggers=[clear_button.click, in_image.clear, im.clear],
+            triggers=[clear_button.click, in_image.clear],
             fn=reset_interface,
-            inputs=[scale_selector],
             outputs=[
-                im,
                 output_image,
                 output_plot,
+                vector_field,
                 in_image,
                 output_table_image2_row,
+                reset_delete_buttons_row,
                 chatbot,
                 results_row,
-                slider,
+                sidebar,
+                row_image_file,
+                row_analysis,
+                image_file,
+                scale_input_status,
+                scale,
+                output_image_row,
             ],
             cancels=[analyze],
             show_progress="hide",
             show_progress_on=question_row,
         )
 
-        scale_selector.change(
+        gr.on(
+            triggers=[scale_selector.change, image_file.change],
             fn=reset_interface2,
-            inputs=[scale_selector],
             outputs=[
                 output_image,
                 output_plot,
-                in_image,
+                vector_field,
                 output_table_image2_row,
+                reset_delete_buttons_row,
                 chatbot,
                 results_row,
+                sidebar,
+                output_image_row,
             ],
             show_progress="hide",
             show_progress_on=question_row,
